# -*- coding: utf-8 -*-

from megrok.menu.component import menuitem, Menu, SubMenuItem

# Provide these directives here as well:
from grokcore.component import name, title, description
from grokcore.viewlet import order
